# Contribute
These are the basic steps for contributing to boundary-layer:

1. Fork from [the master branch](https://github.com/etsy/boundary-layer)
2. Make your changes
3. Document new functionality as appropriate
4. Add new tests if possible
5. Run the test suite with `tox`
6. Push your changes to your fork.
7. Send a pull request!

Every pull request will be built with [Travis CI](https://travis-ci.org/etsy/boundary-layer).  The CI build runs unit tests, [pycodestyle](https://pypi.org/project/pycodestyle/) and [pylint](https://www.pylint.org/).

# Contributors
- Kevin McHale [mchalek](https://github.com/mchalek)
- Jessica Fan [jfantom](https://github.com/jfantom)
- Aaron Niskode-Dossett [dossett](https://github.com/dossett)
- Nikki Thean [nixsticks](https://github.com/nixsticks)
- Julie Chien [jj-ian](https://github.com/jj-ian)
- Andrey Polyakov [andpol](https://github.com/andpol)
